@@ -873,7 +873,7 @@ def test_filecache_with_checks():
 
 @pytest.mark.parametrize("impl", ["filecache", "simplecache", "blockcache"])
 @pytest.mark.parametrize("fs", ["local", "multi"], indirect=["fs"])
-def test_takes_fs_instance(impl, fs):
+def test_filecache_takes_fs_instance(impl, fs):
     origin = tempfile.mkdtemp()
     data = b"test data"
     f1 = os.path.join(origin, "afile")
@@ -885,6 +885,15 @@ def test_takes_fs_instance(impl, fs):
     assert fs2.cat(f1) == data
 
 
+@pytest.mark.parametrize("impl", ["filecache", "simplecache", "blockcache"])
+@pytest.mark.parametrize("fs", ["local", "multi"], indirect=["fs"])
+def test_filecache_serialization(impl, fs):
+    fs1 = fsspec.filesystem(impl, fs=fs)
+    json1 = fs1.to_json()
+
+    assert fs1 is fsspec.AbstractFileSystem.from_json(json1)
+
+
 def test_add_file_to_cache_after_save(local_filecache):
     (data, original_file, cache_location, fs) = local_filecache
 
@@ -1244,7 +1253,7 @@ def test_cache_size(tmpdir, protocol):
     # Remove cached file but leave cache metadata file
     fs.pop_from_cache(afile)
     if win and protocol == "filecache":
-        empty_cache_size < fs.cache_size()
+        assert empty_cache_size < fs.cache_size()
     elif protocol != "simplecache":
         assert empty_cache_size < fs.cache_size() < single_file_cache_size
     else:
@@ -1291,10 +1300,16 @@ def test_write_transaction(tmpdir, m, monkeypatch):
     with fs.transaction:
         fs.pipe("myfile", b"1")
         fs.pipe("otherfile", b"2")
+        fs.pipe("deep/dir/otherfile", b"3")
         with fs.open("blarh", "wb") as f:
             f.write(b"ff")
         assert not m.find("")
 
+        assert fs.info("otherfile")["size"] == 1
+        assert fs.info("deep")["type"] == "directory"
+        assert fs.isdir("deep")
+        assert fs.ls("deep", detail=False) == ["/deep/dir"]
+
     assert m.cat("myfile") == b"1"
     assert m.cat("otherfile") == b"2"
     assert called[0] == 1  # copy was done in one go
