@@ -353,9 +353,7 @@ async def test_async_walk(adirfs, mocker):
     adirfs.fs._walk = mocker.MagicMock()
     adirfs.fs._walk.side_effect = _walk
 
-    actual = []
-    async for entry in adirfs._walk("root", *ARGS, **KWARGS):
-        actual.append(entry)  # noqa: PERF402
+    actual = [entry async for entry in adirfs._walk("root", *ARGS, **KWARGS)]
     assert actual == [("root", ["foo", "bar"], ["baz", "qux"])]
     adirfs.fs._walk.assert_called_once_with(f"{PATH}/root", *ARGS, **KWARGS)
 
@@ -542,10 +540,10 @@ def test_rmdir(mocker, dirfs):
     dirfs.fs.rmdir.assert_called_once_with(f"{PATH}/dir")
 
 
-def test_mv_file(mocker, dirfs):
-    dirfs.fs.mv_file = mocker.Mock()
-    dirfs.mv_file("one", "two", **KWARGS)
-    dirfs.fs.mv_file.assert_called_once_with(f"{PATH}/one", f"{PATH}/two", **KWARGS)
+def test_mv(mocker, dirfs):
+    dirfs.fs.mv = mocker.Mock()
+    dirfs.mv("one", "two", **KWARGS)
+    dirfs.fs.mv.assert_called_once_with(f"{PATH}/one", f"{PATH}/two", **KWARGS)
 
 
 def test_touch(mocker, dirfs):
